@@ -15,7 +15,15 @@
  */
 
 #include "cmnd_edit.h"
+#include "callback_func.h"
+#include "editors.h"
+#include "interface.h"
+#include "geom_edit.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <gtk/gtk.h>
+#include <math.h>
 
 /*------------------------------------------------------------------------*/
 
