@@ -17,9 +17,20 @@
 #ifndef CMND_EDIT_H
 #define CMND_EDIT_H     1
 
-#include "common.h"
-#include "interface.h"
-#include "editors.h"
+/* cmnd_edit.c */
+void Excitation_Command(int action);
+void Frequency_Command(int action);
+void Ground_Command(int action);
+void Ground2_Command(int action);
+void Radiation_Command(int action);
+void Loading_Command(int action);
+void Network_Command(int action);
+void Txline_Command(int action);
+void Nearfield_Command(int action);
+void Kernel_Command(int action);
+void Intrange_Command(int action);
+void Execute_Command(int action);
+void Zo_Command(int action);
 
 #endif
 
