@@ -15,11 +15,26 @@
  */
 
 #include "draw_radiation.h"
+#include "callback_func.h"
+#include "draw.h"
+#include "draw_structure.h"
+#include "interface.h"
 #include "shared.h"
+#include "utils.h"
+#include "xnec2c.h"
+
+#include <gtk/gtk.h>
+#include <math.h>
 
 /* For coloring rad pattern */
 static double *red = NULL, *grn = NULL, *blu = NULL;
 
+/* Point in 3d xyz axes */
+typedef struct
+{
+  double x, y, z, r;
+} point_3d_t;
+
 /* Buffered points in 3d (xyz) space
  * forming the radiation pattern */
 static point_3d_t *point_3d = NULL;
@@ -115,12 +130,12 @@ Draw_Radiation_Pattern( cairo_t *cr )
   if( isFlagSet(DRAW_NEW_RDPAT) )
   {
     size_t mreq = ((size_t)(fpat.nth * fpat.nph)) * sizeof(point_3d_t);
-    mem_realloc( (void **)&point_3d, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&point_3d, mreq, "in draw_radiation.c" );
     mreq = (size_t)((fpat.nth-1) * fpat.nph + (fpat.nph-1) * fpat.nth);
     mreq *= sizeof(double);
-    mem_realloc( (void **)&red, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&grn, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&blu, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&red, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&grn, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&blu, mreq, "in draw_radiation.c" );
 
     ClearFlag( DRAW_NEW_RDPAT );
 
@@ -490,10 +505,10 @@ Draw_Near_Field( cairo_t *cr )
       if( !mreq || isFlagSet(ALLOC_PNTING_BUFF) )
       {
         mreq = (size_t)npts * sizeof( double );
-        mem_realloc( (void **)&pov_x, mreq, "in draw_radiation.c" );
-        mem_realloc( (void **)&pov_y, mreq, "in draw_radiation.c" );
-        mem_realloc( (void **)&pov_z, mreq, "in draw_radiation.c" );
-        mem_realloc( (void **)&pov_r, mreq, "in draw_radiation.c" );
+        Mem_Realloc( (void **)&pov_x, mreq, "in draw_radiation.c" );
+        Mem_Realloc( (void **)&pov_y, mreq, "in draw_radiation.c" );
+        Mem_Realloc( (void **)&pov_z, mreq, "in draw_radiation.c" );
+        Mem_Realloc( (void **)&pov_r, mreq, "in draw_radiation.c" );
         ClearFlag( ALLOC_PNTING_BUFF );
       }
 
@@ -583,7 +598,8 @@ Draw_Near_Field( cairo_t *cr )
 Draw_Radiation( cairo_t *cr )
 {
   /* Abort if xnec2c may be quit by user */
-  if( isFlagSet(MAIN_QUIT) || isFlagClear(ENABLE_EXCITN) )
+  //if( isFlagSet(MAIN_QUIT) || isFlagClear(ENABLE_EXCITN) )
+  if( isFlagClear(ENABLE_EXCITN) )
     return;
 
   /* Don't draw radiation pattern when freq
@@ -765,7 +781,7 @@ Set_Polarization( int pol )
   if( isFlagSet(PLOT_ENABLED) )
   {
     /* Wait for GTK to complete its tasks */
-    gtk_widget_queue_draw( freqplots_drawingarea );
+    gtk_widget_queue_draw( plots_drawingarea );
     //while( g_main_context_iteration(NULL, FALSE) );
   }
 
@@ -827,7 +843,7 @@ New_Radiation_Projection_Angle(void)
       isFlagClear(OPTIMIZER_OUTPUT) )
   {
     /* Wait for GTK to complete its tasks */
-    gtk_widget_queue_draw( freqplots_drawingarea );
+    gtk_widget_queue_draw( plots_drawingarea );
     //while( g_main_context_iteration(NULL, FALSE) );
   }
 
@@ -1012,7 +1028,7 @@ Set_Window_Labels( void )
     Strlcpy( txt, _("Frequency Data Plots - "), s );
     Strlcat( txt, pol_type[calc_data.pol_type], s );
     gtk_label_set_text( GTK_LABEL(Builder_Get_Object(
-            freqplots_window_builder, "freqplots_label")), txt );
+            plots_window_builder, "plots_label")), txt );
   }
 
 } /* Set_Window_Labels() */
@@ -1033,52 +1049,52 @@ Alloc_Rdpattern_Buffers( int nfrq, int nth, int nph )
   /* Free old gain buffers first */
   for( idx = 0; idx < last_nfrq; idx++ )
   {
-    free_ptr( (void **)&rad_pattern[idx].gtot );
-    free_ptr( (void **)&rad_pattern[idx].max_gain );
-    free_ptr( (void **)&rad_pattern[idx].min_gain );
-    free_ptr( (void **)&rad_pattern[idx].max_gain_tht );
-    free_ptr( (void **)&rad_pattern[idx].max_gain_phi );
-    free_ptr( (void **)&rad_pattern[idx].max_gain_idx );
-    free_ptr( (void **)&rad_pattern[idx].min_gain_idx );
-    free_ptr( (void **)&rad_pattern[idx].axrt );
-    free_ptr( (void **)&rad_pattern[idx].tilt );
-    free_ptr( (void **)&rad_pattern[idx].sens );
+    Mem_Free( (void **)&rad_pattern[idx].gtot );
+    Mem_Free( (void **)&rad_pattern[idx].max_gain );
+    Mem_Free( (void **)&rad_pattern[idx].min_gain );
+    Mem_Free( (void **)&rad_pattern[idx].max_gain_tht );
+    Mem_Free( (void **)&rad_pattern[idx].max_gain_phi );
+    Mem_Free( (void **)&rad_pattern[idx].max_gain_idx );
+    Mem_Free( (void **)&rad_pattern[idx].min_gain_idx );
+    Mem_Free( (void **)&rad_pattern[idx].axrt );
+    Mem_Free( (void **)&rad_pattern[idx].tilt );
+    Mem_Free( (void **)&rad_pattern[idx].sens );
   }
   last_nfrq = nfrq;
 
   /* Allocate rad pattern buffers */
   mreq = (size_t)nfrq * sizeof(rad_pattern_t);
-  mem_realloc( (void **)&rad_pattern, mreq, "in draw_radiation.c" );
+  Mem_Realloc( (void **)&rad_pattern, mreq, "in draw_radiation.c" );
   for( idx = 0; idx < nfrq; idx++ )
   {
     /* Memory request for allocs */
     mreq = (size_t)(nph * nth) * sizeof(double);
     rad_pattern[idx].gtot = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].gtot), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].gtot), mreq, "in draw_radiation.c" );
     rad_pattern[idx].axrt = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].axrt), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].axrt), mreq, "in draw_radiation.c" );
     rad_pattern[idx].tilt = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].tilt), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].tilt), mreq, "in draw_radiation.c" );
 
     mreq = NUM_POL * sizeof(double);
     rad_pattern[idx].max_gain = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].max_gain), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].max_gain), mreq, "in draw_radiation.c" );
     rad_pattern[idx].min_gain = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].min_gain), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].min_gain), mreq, "in draw_radiation.c" );
     rad_pattern[idx].max_gain_tht = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].max_gain_tht), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].max_gain_tht), mreq, "in draw_radiation.c" );
     rad_pattern[idx].max_gain_phi = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].max_gain_phi), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].max_gain_phi), mreq, "in draw_radiation.c" );
 
     mreq = NUM_POL * sizeof(int);
     rad_pattern[idx].max_gain_idx = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].max_gain_idx), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].max_gain_idx), mreq, "in draw_radiation.c" );
     rad_pattern[idx].min_gain_idx = NULL;
-    mem_alloc( (void **)&(rad_pattern[idx].min_gain_idx), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].min_gain_idx), mreq, "in draw_radiation.c" );
 
     rad_pattern[idx].sens = NULL;
     mreq = (size_t)(nph * nth) * sizeof(int);
-    mem_alloc( (void **)&(rad_pattern[idx].sens), mreq, "in draw_radiation.c" );
+    Mem_Alloc( (void **)&(rad_pattern[idx].sens), mreq, "in draw_radiation.c" );
   }
 
 } /* Alloc_Rdpattern_Buffers() */
@@ -1103,35 +1119,35 @@ Alloc_Nearfield_Buffers( int n1, int n2, int n3 )
   /* Allocate near field buffers */
   if( fpat.nfeh & NEAR_EFIELD )
   {
-    mem_realloc( (void **)&near_field.ex,  mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.ey,  mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.ez,  mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.fex, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.fey, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.fez, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.erx, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.ery, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.erz, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.er,  mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.ex,  mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.ey,  mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.ez,  mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.fex, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.fey, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.fez, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.erx, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.ery, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.erz, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.er,  mreq, "in draw_radiation.c" );
   }
 
   if( fpat.nfeh & NEAR_HFIELD )
   {
-    mem_realloc( (void **)&near_field.hx,  mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.hy,  mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.hz,  mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.fhx, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.fhy, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.fhz, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.hrx, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.hry, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.hrz, mreq, "in draw_radiation.c" );
-    mem_realloc( (void **)&near_field.hr,  mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.hx,  mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.hy,  mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.hz,  mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.fhx, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.fhy, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.fhz, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.hrx, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.hry, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.hrz, mreq, "in draw_radiation.c" );
+    Mem_Realloc( (void **)&near_field.hr,  mreq, "in draw_radiation.c" );
   }
 
-  mem_realloc( (void **)&near_field.px, mreq, "in draw_radiation.c" );
-  mem_realloc( (void **)&near_field.py, mreq, "in draw_radiation.c" );
-  mem_realloc( (void **)&near_field.pz, mreq, "in draw_radiation.c" );
+  Mem_Realloc( (void **)&near_field.px, mreq, "in draw_radiation.c" );
+  Mem_Realloc( (void **)&near_field.py, mreq, "in draw_radiation.c" );
+  Mem_Realloc( (void **)&near_field.pz, mreq, "in draw_radiation.c" );
 
 } /* Alloc_Nearfield_Buffers() */
 
@@ -1144,10 +1160,10 @@ Alloc_Nearfield_Buffers( int n1, int n2, int n3 )
   void
 Free_Draw_Buffers( void )
 {
-  free_ptr( (void **)&point_3d );
-  free_ptr( (void **)&red );
-  free_ptr( (void **)&grn );
-  free_ptr( (void **)&blu );
+  Mem_Free( (void **)&point_3d );
+  Mem_Free( (void **)&red );
+  Mem_Free( (void **)&grn );
+  Mem_Free( (void **)&blu );
 }
 
 /*-----------------------------------------------------------------------*/
