@@ -15,7 +15,20 @@
  */
 
 #include "draw_structure.h"
+#include "draw_radiation.h"
+#include "draw.h"
+#include "interface.h"
 #include "shared.h"
+#include "utils.h"
+#include "xnec2c.h"
+
+#include <complex.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
 
 /*-----------------------------------------------------------------------*/
 
@@ -27,7 +40,7 @@
 Draw_Structure( cairo_t *cr )
 {
   /* Abort if xnec2c may be quit by user */
-  if( isFlagSet(MAIN_QUIT) ) return;
+  //if( isFlagSet(MAIN_QUIT) ) return;
 
   /* Clear drawingarea */
   cairo_set_source_rgb( cr, BLACK );
@@ -136,12 +149,12 @@ New_Patch_Data( void )
 
   /* Allocate memory for patch line segments */
   mreq = (size_t)(2 * data.m) * sizeof(double);
-  mem_realloc( (void **)&data.px1, mreq, "in draw_structure.c" );
-  mem_realloc( (void **)&data.py1, mreq, "in draw_structure.c" );
-  mem_realloc( (void **)&data.pz1, mreq, "in draw_structure.c" );
-  mem_realloc( (void **)&data.px2, mreq, "in draw_structure.c" );
-  mem_realloc( (void **)&data.py2, mreq, "in draw_structure.c" );
-  mem_realloc( (void **)&data.pz2, mreq, "in draw_structure.c" );
+  Mem_Realloc( (void **)&data.px1, mreq, "in draw_structure.c" );
+  Mem_Realloc( (void **)&data.py1, mreq, "in draw_structure.c" );
+  Mem_Realloc( (void **)&data.pz1, mreq, "in draw_structure.c" );
+  Mem_Realloc( (void **)&data.px2, mreq, "in draw_structure.c" );
+  Mem_Realloc( (void **)&data.py2, mreq, "in draw_structure.c" );
+  Mem_Realloc( (void **)&data.pz2, mreq, "in draw_structure.c" );
 
   /* Find point furthest from xyz axes origin */
   r_max = 0.0;
@@ -623,7 +636,7 @@ Redo_Currents( gpointer udata )
   if( isFlagSet(PLOT_FREQ_LINE) )
   {
     /* Wait for GTK to complete its tasks */
-    gtk_widget_queue_draw( freqplots_drawingarea );
+    gtk_widget_queue_draw( plots_drawingarea );
     //while( g_main_context_iteration(NULL, FALSE) );
   }
 
@@ -669,7 +682,7 @@ New_Structure_Projection_Angle(void)
       isFlagClear(OPTIMIZER_OUTPUT) )
   {
     /* Wait for GTK to complete its tasks */
-    gtk_widget_queue_draw( freqplots_drawingarea );
+    gtk_widget_queue_draw( plots_drawingarea );
     //while( g_main_context_iteration(NULL, FALSE) );
   }
 
@@ -686,7 +699,7 @@ Init_Struct_Drawing( void )
 {
   /* We need n segs for wires + 2m for patces */
   size_t mreq = (size_t)(data.n + 2*data.m) * sizeof(Segment_t);
-  mem_realloc( (void **)&structure_segs, mreq, "in draw_structure.c" );
+  Mem_Realloc( (void **)&structure_segs, mreq, "in draw_structure.c" );
   New_Wire_Data();
   New_Patch_Data();
 }
