@@ -17,7 +17,20 @@
 #ifndef DRAW_STRUCTURE_H
 #define DRAW_STRUCTURE_H        1
 
-#include "common.h"
+#include "shared.h"
+#include <gtk/gtk.h>
+
+/* draw_structure.c */
+void Draw_Structure(cairo_t *cr);
+void New_Patch_Data(void);
+void Process_Wire_Segments(void);
+void Process_Surface_Patches(void);
+void Draw_Wire_Segments(cairo_t *cr, Segment_t *segm, gint nseg);
+void Draw_Surface_Patches(cairo_t *cr, Segment_t *segm, gint npatch);
+gboolean Redo_Currents(gpointer udata);
+void New_Structure_Projection_Angle(void);
+void Init_Struct_Drawing(void);
+void Show_Viewer_Gain(GtkBuilder *builder, gchar *widget, projection_parameters_t proj_params);
 
 #endif
 
