@@ -15,7 +15,13 @@
  */
 
 #include "geom_edit.h"
+#include "callback_func.h"
+#include "editors.h"
+#include "interface.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <math.h>
 
 /*------------------------------------------------------------------------*/
 
