@@ -17,13 +17,26 @@
 #ifndef GEOM_EDIT_H
 #define GEOM_EDIT_H     1
 
-#include "common.h"
-#include "interface.h"
-#include "editors.h"
+#include <gtk/gtk.h>
 
 /* Default values for helix editor */
 #define HELIX_SEG_TURN  8
 #define HELIX_LENGTH    5.0
 
+/* geom_edit.c */
+void Wire_Editor(int action);
+void Patch_Editor(int action);
+void Arc_Editor(int action);
+void Helix_Editor(int action);
+void Reflect_Editor(int action);
+void Scale_Editor(int action);
+void Cylinder_Editor(int action);
+void Transform_Editor(int action);
+void Gend_Editor(int action);
+gboolean Check_Card_Name(GtkListStore *store, GtkTreeIter *iter, gboolean next, const gchar *name);
+gboolean Give_Up(gboolean *busy, GtkWidget *widget);
+void Remove_Row(GtkListStore *store, GtkTreeIter *iter);
+gboolean Get_Selected_Row(GtkTreeView *view, GtkListStore *store, GtkTreeIter *iter, gchar *name);
+
 #endif
 
