@@ -40,7 +40,18 @@
  ***********************************************************************/
 
 #include "ground.h"
+#include "calculations.h"
+#include "fields.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <complex.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
 
 /*-------------------------------------------------------------------*/
 
@@ -68,14 +79,14 @@ rom2( double a, double b,
   {
     first_call = FALSE;
     size_t mreq = 9 * sizeof(complex double);
-    mem_alloc( (void **)&g1, mreq, "in ground.c");
-    mem_alloc( (void **)&g2, mreq, "in ground.c");
-    mem_alloc( (void **)&g3, mreq, "in ground.c");
-    mem_alloc( (void **)&g4, mreq, "in ground.c");
-    mem_alloc( (void **)&g5, mreq, "in ground.c");
-    mem_alloc( (void **)&t01, mreq, "in ground.c");
-    mem_alloc( (void **)&t10, mreq, "in ground.c");
-    mem_alloc( (void **)&t20, mreq, "in ground.c");
+    Mem_Alloc( (void **)&g1, mreq, "in ground.c");
+    Mem_Alloc( (void **)&g2, mreq, "in ground.c");
+    Mem_Alloc( (void **)&g3, mreq, "in ground.c");
+    Mem_Alloc( (void **)&g4, mreq, "in ground.c");
+    Mem_Alloc( (void **)&g5, mreq, "in ground.c");
+    Mem_Alloc( (void **)&t01, mreq, "in ground.c");
+    Mem_Alloc( (void **)&t10, mreq, "in ground.c");
+    Mem_Alloc( (void **)&t20, mreq, "in ground.c");
   }
 
   z= a;
