@@ -17,7 +17,16 @@
 #ifndef GROUND_H
 #define GROUND_H        1
 
-#include "common.h"
+#include <complex.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+/* ground.c */
+void rom2(double a, double b, _Complex double *sum, double dmin);
+void sflds(double t, _Complex double *e);
 
 #endif
 
