@@ -40,7 +40,73 @@
  ***********************************************************************/
 
 #include "input.h"
+#include "draw_structure.h"
+#include "draw_radiation.h"
+#include "geometry.h"
+#include "interface.h"
+#include "main.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <ctype.h>
+#include <gtk/gtk.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+#define COMMANDS \
+  "CM", "CP", "EK", "EN", "EX", \
+  "FR", "GD", "GN", "KH", "LD", \
+  "NE", "NH", "NT", "PQ", "PT", \
+  "RP", "SY", "TL", "XQ", "ZO"
+
+/* Command Mnemonics */
+enum CMND_MNM
+{
+  CM = 0,
+  CP,
+  EK,
+  EN,
+  EX,
+  FR,
+  GD,
+  GN,
+  KH,
+  LD,
+  NE,
+  NH,
+  NT,
+  PQ,
+  PT,
+  RP,
+  SY,
+  TL,
+  XQ,
+  ZO,
+  NUM_CMNDS
+};
+
+/* Geometry Mnemonics */
+enum GEOM_MNM
+{
+  GW = 0,
+  GX,
+  GR,
+  GS,
+  GE,
+  GM,
+  SP,
+  SM,
+  GA,
+  SC,
+  GH,
+  GF,
+  CT,
+  NUM_GEOMN
+};
 
 /*------------------------------------------------------------------------*/
 
@@ -121,13 +187,14 @@ Tag_Seg_Error( int tag, int segs )
     retv = TRUE;
   }
 
-  if( segs <= 0 )
+  // This is to silence warnings from Coverity scanner
+  if( (segs < 1) || (segs > 1000000) )
   {
     fprintf( stderr,
         _("xnec2c: Tag_Seg_Error(): geometry data card error - "
-        "number of segments is less than 1\n") );
+        "number of segments out of bounds\n") );
     Stop( _("Tag_Seg_Error(): Geometry data error\n"
-          "Number of segments is less than 1"), ERR_OK );
+          "Number of segments out of bounds"), ERR_OK );
     retv = TRUE;
   }
 
@@ -218,7 +285,7 @@ datagn( void )
           ys1= pow( (zs1/ys1), (1.0/(ns-1.0)) );
         }
 
-        wire( xw1, yw1, zw1, xw2, yw2, zw2, rad, xs1, ys1, ns, itg);
+        wire( xw1, yw1, zw1, xw2, yw2, zw2, rad, xs1, ys1, ns, itg );
         continue;
 
         /* reflect structure along x,y, or z */
@@ -318,13 +385,13 @@ datagn( void )
         {
           /* Allocate wire buffers */
           mreq = (size_t)data.n * sizeof(double);
-          mem_realloc( (void **)&data.si,   mreq, "in input.c" );
-          mem_realloc( (void **)&data.sab,  mreq, "in input.c" );
-          mem_realloc( (void **)&data.cab,  mreq, "in input.c" );
-          mem_realloc( (void **)&data.salp, mreq, "in input.c" );
-          mem_realloc( (void **)&data.x, mreq, "in input.c" );
-          mem_realloc( (void **)&data.y, mreq, "in input.c" );
-          mem_realloc( (void **)&data.z, mreq, "in input.c" );
+          Mem_Realloc( (void **)&data.si,   mreq, "in input.c" );
+          Mem_Realloc( (void **)&data.sab,  mreq, "in input.c" );
+          Mem_Realloc( (void **)&data.cab,  mreq, "in input.c" );
+          Mem_Realloc( (void **)&data.salp, mreq, "in input.c" );
+          Mem_Realloc( (void **)&data.x, mreq, "in input.c" );
+          Mem_Realloc( (void **)&data.y, mreq, "in input.c" );
+          Mem_Realloc( (void **)&data.z, mreq, "in input.c" );
 
           for( i = 0; i < data.n; i++ )
           {
@@ -590,34 +657,34 @@ Read_Geometry( void )
 
   /* Memory allocation for temporary buffers */
   mreq = (size_t)data.npm * sizeof(double);
-  mem_realloc( (void **)&save.xtemp,  mreq, "in input.c" );
-  mem_realloc( (void **)&save.ytemp,  mreq, "in input.c" );
-  mem_realloc( (void **)&save.ztemp,  mreq, "in input.c" );
-  mem_realloc( (void **)&save.bitemp, mreq, "in input.c" );
+  Mem_Realloc( (void **)&save.xtemp,  mreq, "in input.c" );
+  Mem_Realloc( (void **)&save.ytemp,  mreq, "in input.c" );
+  Mem_Realloc( (void **)&save.ztemp,  mreq, "in input.c" );
+  Mem_Realloc( (void **)&save.bitemp, mreq, "in input.c" );
   if( data.n > 0 )
   {
     mreq = (size_t)data.n * sizeof(double);
-    mem_realloc( (void **)&save.sitemp, mreq, "in input.c" );
+    Mem_Realloc( (void **)&save.sitemp, mreq, "in input.c" );
   }
 
   /* Memory allocation for primary interacton matrix. */
   mreq = (size_t)(data.np2m * (data.np + 2 * data.mp)) * sizeof(complex double);
-  mem_realloc( (void **)&cm, mreq, "in input.c" );
+  Mem_Realloc( (void **)&cm, mreq, "in input.c" );
 
   /* Memory allocation for current buffers */
   mreq = (size_t)data.npm * sizeof( double);
-  mem_realloc( (void **)&crnt.air, mreq, "in input.c" );
-  mem_realloc( (void **)&crnt.aii, mreq, "in input.c" );
-  mem_realloc( (void **)&crnt.bir, mreq, "in input.c" );
-  mem_realloc( (void **)&crnt.bii, mreq, "in input.c" );
-  mem_realloc( (void **)&crnt.cir, mreq, "in input.c" );
-  mem_realloc( (void **)&crnt.cii, mreq, "in input.c" );
+  Mem_Realloc( (void **)&crnt.air, mreq, "in input.c" );
+  Mem_Realloc( (void **)&crnt.aii, mreq, "in input.c" );
+  Mem_Realloc( (void **)&crnt.bir, mreq, "in input.c" );
+  Mem_Realloc( (void **)&crnt.bii, mreq, "in input.c" );
+  Mem_Realloc( (void **)&crnt.cir, mreq, "in input.c" );
+  Mem_Realloc( (void **)&crnt.cii, mreq, "in input.c" );
   mreq = (size_t)data.np3m * sizeof( complex double);
-  mem_realloc( (void **)&crnt.cur, mreq, "in input.c" );
+  Mem_Realloc( (void **)&crnt.cur, mreq, "in input.c" );
 
   /* Memory allocation for loading buffers */
   mreq = (size_t)data.npm * sizeof(complex double);
-  mem_realloc( (void **)&zload.zarray, mreq, "in input.c" );
+  Mem_Realloc( (void **)&zload.zarray, mreq, "in input.c" );
 
   /* Save segment and patch data for freq scaling */
   if( data.n > 0 )
@@ -712,12 +779,12 @@ Read_Commands( void )
 
   /* Allocate some buffers */
   mreq = (size_t)data.np2m * sizeof(int);
-  mem_realloc( (void **)&save.ip, mreq, "in input.c" );
+  Mem_Realloc( (void **)&save.ip, mreq, "in input.c" );
 
   /* Memory allocation for symmetry array */
   smat.nop = netcx.neq/netcx.npeq;
   mreq = (size_t)(smat.nop * smat.nop) * sizeof( complex double);
-  mem_realloc( (void **)&smat.ssx, mreq, "in input.c" );
+  Mem_Realloc( (void **)&smat.ssx, mreq, "in input.c" );
 
   /* main input section, exits at various points */
   /* depending on error conditions or end of job */
@@ -743,8 +810,7 @@ Read_Commands( void )
       case CM: /* "cm" card ignored, comments in data cards as in NEC4 */
         fprintf( stderr, _("xnec2c: Read_Commands():"
             " ignoring CM card in commands\n") );
-        Stop( _("Read_Commands(): Ignoring CM card in commands"),
-            ERR_OK );
+        Stop( _("Read_Commands(): Ignoring CM card in commands"), ERR_OK );
         continue;
 
       case CP: /* "cp" card ignored, maximum coupling between antennas */
@@ -776,11 +842,11 @@ Read_Commands( void )
           {
             vsorc.nvqd++;
             mreq = (size_t)vsorc.nvqd * sizeof(int);
-            mem_realloc( (void **)&vsorc.ivqd, mreq, "in input.c" );
-            mem_realloc( (void **)&vsorc.iqds, mreq, "in input.c" );
+            Mem_Realloc( (void **)&vsorc.ivqd, mreq, "in input.c" );
+            Mem_Realloc( (void **)&vsorc.iqds, mreq, "in input.c" );
             mreq = (size_t)vsorc.nvqd * sizeof(complex double);
-            mem_realloc( (void **)&vsorc.vqd, mreq, "in input.c" );
-            mem_realloc( (void **)&vsorc.vqds, mreq, "in input.c" );
+            Mem_Realloc( (void **)&vsorc.vqd, mreq, "in input.c" );
+            Mem_Realloc( (void **)&vsorc.vqds, mreq, "in input.c" );
             {
               int indx = vsorc.nvqd-1;
 
@@ -800,9 +866,9 @@ Read_Commands( void )
             /* Else, applied E field */
             vsorc.nsant++;
             mreq = (size_t)vsorc.nsant * sizeof(int);
-            mem_realloc( (void **)&vsorc.isant, mreq, "in input.c" );
+            Mem_Realloc( (void **)&vsorc.isant, mreq, "in input.c" );
             mreq = (size_t)vsorc.nsant * sizeof(complex double);
-            mem_realloc( (void **)&vsorc.vsant, mreq, "in input.c" );
+            Mem_Realloc( (void **)&vsorc.vsant, mreq, "in input.c" );
             {
               int indx = vsorc.nsant-1;
 
@@ -847,7 +913,7 @@ Read_Commands( void )
 
         /* Allocate the frequency data structure pointer FIXME */
         mreq = (size_t)calc_data.FR_cards * sizeof(freq_loop_data_t);
-        mem_realloc( (void **) &(calc_data.freq_loop_data), mreq, "in input.c" );
+        Mem_Realloc( (void **) &(calc_data.freq_loop_data), mreq, "in input.c" );
 
         /* Short cuts */
         freq_loop_data_t *fld = calc_data.freq_loop_data;
@@ -870,14 +936,14 @@ Read_Commands( void )
         {
           calc_data.steps_total += fld[card].freq_steps;
           mreq = (size_t)calc_data.steps_total * sizeof(double);
-          mem_realloc( (void **) &(impedance_data.zreal),  mreq, "in input.c" );
-          mem_realloc( (void **) &(impedance_data.zimag),  mreq, "in input.c" );
-          mem_realloc( (void **) &(impedance_data.zmagn),  mreq, "in input.c" );
-          mem_realloc( (void **) &(impedance_data.zphase), mreq, "in input.c" );
-          mem_realloc( (void **) &(save.freq), mreq, "in input.c" );
+          Mem_Realloc( (void **) &(impedance_data.zreal),  mreq, "in input.c" );
+          Mem_Realloc( (void **) &(impedance_data.zimag),  mreq, "in input.c" );
+          Mem_Realloc( (void **) &(impedance_data.zmagn),  mreq, "in input.c" );
+          Mem_Realloc( (void **) &(impedance_data.zphase), mreq, "in input.c" );
+          Mem_Realloc( (void **) &(save.freq), mreq, "in input.c" );
 
           mreq = (size_t)calc_data.steps_total * sizeof(char);
-          mem_realloc( (void **) &(save.fstep), mreq, "in input.c" );
+          Mem_Realloc( (void **) &(save.fstep), mreq, "in input.c" );
         }
 
         if( CHILD ) continue;
@@ -1000,15 +1066,15 @@ Read_Commands( void )
           /* Reallocate loading buffers */
           zload.nload++;
           mreq = (size_t)zload.nload * sizeof(int);
-          mem_realloc( (void **)&calc_data.ldtyp,  mreq, "in input.c" );
-          mem_realloc( (void **)&calc_data.ldtag,  mreq, "in input.c" );
-          mem_realloc( (void **)&calc_data.ldtagf, mreq, "in input.c" );
-          mem_realloc( (void **)&calc_data.ldtagt, mreq, "in input.c" );
+          Mem_Realloc( (void **)&calc_data.ldtyp,  mreq, "in input.c" );
+          Mem_Realloc( (void **)&calc_data.ldtag,  mreq, "in input.c" );
+          Mem_Realloc( (void **)&calc_data.ldtagf, mreq, "in input.c" );
+          Mem_Realloc( (void **)&calc_data.ldtagt, mreq, "in input.c" );
 
           mreq = (size_t)zload.nload * sizeof(double);
-          mem_realloc( (void **)&calc_data.zlr, mreq, "in input.c" );
-          mem_realloc( (void **)&calc_data.zli, mreq, "in input.c" );
-          mem_realloc( (void **)&calc_data.zlc, mreq, "in input.c" );
+          Mem_Realloc( (void **)&calc_data.zlr, mreq, "in input.c" );
+          Mem_Realloc( (void **)&calc_data.zli, mreq, "in input.c" );
+          Mem_Realloc( (void **)&calc_data.zlc, mreq, "in input.c" );
 
           idx = zload.nload-1;
           calc_data.ldtyp[idx]= itmp1;
@@ -1042,8 +1108,8 @@ Read_Commands( void )
             {
               nseg = data.n;
               mreq = (size_t)(nseg + zload.nldseg) * sizeof(int);
-              mem_realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
-              mem_realloc( (void **)&zload.ldtype, mreq, "in input.c" );
+              Mem_Realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
+              Mem_Realloc( (void **)&zload.ldtype, mreq, "in input.c" );
               for( idx = 0; idx < nseg; idx++ )
               {
                 zload.ldtype[zload.nldseg]   = itmp1;
@@ -1055,8 +1121,8 @@ Read_Commands( void )
               nseg = itmp4 - itmp3 + 1;
               if( nseg <= 0 ) nseg = 1;
               mreq = (size_t)(nseg + zload.nldseg) * sizeof(int);
-              mem_realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
-              mem_realloc( (void **)&zload.ldtype, mreq, "in input.c" );
+              Mem_Realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
+              Mem_Realloc( (void **)&zload.ldtype, mreq, "in input.c" );
               for( idx = 0; idx < nseg; idx++ )
               {
                 zload.ldtype[zload.nldseg]   = itmp1;
@@ -1073,8 +1139,8 @@ Read_Commands( void )
                 if( data.itag[idx] == itmp2 )
                 {
                   mreq = (size_t)(zload.nldseg + 1) * sizeof(int);
-                  mem_realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
-                  mem_realloc( (void **)&zload.ldtype, mreq, "in input.c" );
+                  Mem_Realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
+                  Mem_Realloc( (void **)&zload.ldtype, mreq, "in input.c" );
                   zload.ldtype[zload.nldseg]   = itmp1;
                   zload.ldsegn[zload.nldseg++] = idx+1;
                 }
@@ -1084,8 +1150,8 @@ Read_Commands( void )
               nseg = itmp4 - itmp3 + 1;
               if( nseg <= 0 ) nseg = 1; /* Just one seg of tag (=itmp3) */
               mreq = (size_t)(zload.nldseg + nseg) * sizeof(int);
-              mem_realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
-              mem_realloc( (void **)&zload.ldtype, mreq, "in input.c" );
+              Mem_Realloc( (void **)&zload.ldsegn, mreq, "in input.c" );
+              Mem_Realloc( (void **)&zload.ldtype, mreq, "in input.c" );
               for( idx = 0; idx < nseg; idx++ )
               {
                 zload.ldtype[zload.nldseg] = itmp1;
@@ -1136,17 +1202,17 @@ Read_Commands( void )
           /* Re-allocate network buffers */
           netcx.nonet++;
           mreq = (size_t)netcx.nonet * sizeof(int);
-          mem_realloc( (void **)&netcx.ntyp,  mreq, "in input.c" );
-          mem_realloc( (void **)&netcx.iseg1, mreq, "in input.c" );
-          mem_realloc( (void **)&netcx.iseg2, mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.ntyp,  mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.iseg1, mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.iseg2, mreq, "in input.c" );
 
           mreq = (size_t)netcx.nonet * sizeof(double);
-          mem_realloc( (void **)&netcx.x11r, mreq, "in input.c" );
-          mem_realloc( (void **)&netcx.x11i, mreq, "in input.c" );
-          mem_realloc( (void **)&netcx.x12r, mreq, "in input.c" );
-          mem_realloc( (void **)&netcx.x12i, mreq, "in input.c" );
-          mem_realloc( (void **)&netcx.x22r, mreq, "in input.c" );
-          mem_realloc( (void **)&netcx.x22i, mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.x11r, mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.x11i, mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.x12r, mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.x12i, mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.x22r, mreq, "in input.c" );
+          Mem_Realloc( (void **)&netcx.x22i, mreq, "in input.c" );
 
           idx = netcx.nonet-1;
           if( ain_num == 12 )
@@ -1303,10 +1369,10 @@ Read_Commands( void )
         calc_data.zo = (double)itmp1;
 
         /* Set the Zo spinbutton value */
-        if( freqplots_window_builder )
+        if( plots_window_builder )
         {
           GtkWidget *spin = Builder_Get_Object(
-              freqplots_window_builder, "freqplots_zo_spinbutton" );
+              plots_window_builder, "plots_zo_spinbutton" );
           gtk_spin_button_set_value( GTK_SPIN_BUTTON(spin), (gdouble)calc_data.zo );
         }
         continue;
@@ -1330,21 +1396,6 @@ Read_Commands( void )
       SetFlag( ENABLE_RDPAT );
     }
 
-    /* Reject FR cards that are not in ascending frequency order */
-    freq_loop_data_t *fld = calc_data.freq_loop_data;
-    for( int idx = 1; idx < calc_data.FR_cards; idx++ )
-    {
-      if( fld[idx].min_freq <= fld[idx-1].max_freq )
-      {
-        fprintf( stderr,
-            _("xnec2c: Read_Commands(): FR cards in incorrect order: prev=%f, cur=%f\n"),
-            fld[idx-1].max_freq, fld[idx].min_freq );
-        Stop( _("Read_Commands(): FR cards not in ascending\n"
-              "frequency order or frequency ranges overlapping."), ERR_OK );
-        return( FALSE );
-      }
-    }
-
     return( TRUE );
   } /* while( TRUE ) */
 
@@ -1373,7 +1424,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
   *f1 = *f2 = *f3 = *f4 = *f5 = *f6 = 0.0;
 
   /* read a line from input file */
-  mem_alloc((void **)&line_buf, LINE_LEN, "in readmn()");
+  Mem_Alloc((void **)&line_buf, LINE_LEN, "in readmn()");
   if( line_buf == NULL ) return( FALSE );
   startptr = line_buf;
   eof = Load_Line( line_buf, input_fp );
@@ -1393,7 +1444,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
     Stop( _("readmn(): Command data card error\n"
           "Unexpected EOF while reading input file\n"
             "Uppending a default EN card"), ERR_OK );
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( FALSE );
   }
 
@@ -1409,7 +1460,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
         "card's mnemonic code too short or missing\n") );
     Stop( _("readmn(): Command data card error\n"
           "Mnemonic code too short or missing"), ERR_OK );
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( FALSE );
   }
 
@@ -1419,14 +1470,14 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
   /* Return if only mnemonic on card */
   if( len == 2 )
   {
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( TRUE );
   }
 
   /* Compatibility with NEC4, comments between data cards */
   if( strncmp(mn, "CM", 2) == 0 )
   {
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( TRUE );
   }
 
@@ -1456,7 +1507,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
         mn, line_buf[idx], idx+1 );
     Stop( _("readmn(): Command data card error\n"
           "Spurious character in command card"), ERR_OK );
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( FALSE );
   }
 
@@ -1483,7 +1534,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
     *f4= rarr[3];
     *f5= rarr[4];
     *f6= rarr[5];
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( TRUE );
   }
 
@@ -1508,7 +1559,7 @@ readmn( char *mn, int *i1, int *i2, int *i3, int *i4,
   *f5= rarr[4];
   *f6= rarr[5];
 
-  free_ptr( (void **)&startptr );
+  Mem_Free( (void **)&startptr );
   return( TRUE );
 } /* readmn() */
 
@@ -1535,7 +1586,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
   *x1 = *y1 = *z1 = *x2 = *y2 = *z2 = *rad = 0.0;
 
   /* read a line from input file */
-  mem_alloc((void **)&line_buf, LINE_LEN, "in readgm()");
+  Mem_Alloc((void **)&line_buf, LINE_LEN, "in readgm()");
   if( line_buf == NULL ) return( FALSE );
   startptr = line_buf;
    eof = Load_Line( line_buf, input_fp );
@@ -1555,7 +1606,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
     Stop( _("readgm(): Geometry data card error\n"
           "Unexpected EOF while reading input file\n"
           "Uppending a default GE card"), ERR_OK );
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( FALSE );
   }
 
@@ -1571,7 +1622,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
         "card's mnemonic code too short or missing\n") );
     Stop( _("readgm(): Geometry data card error\n"
           "Card's mnemonic code too short or missing"), ERR_OK );
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( FALSE );
   }
 
@@ -1581,7 +1632,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
   /* Return if only mnemonic on card */
   if( len == 2 )
   {
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( TRUE );
   }
 
@@ -1589,7 +1640,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
    * comments between data cards */
   if( strcmp(gm, "CM") == 0 )
   {
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( TRUE );
   }
 
@@ -1619,7 +1670,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
         gm, line_buf[idx], idx+1 );
     Stop( _("readmn(): Geometry data card error\n"
           "Spurious character in command card"), ERR_OK );
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( FALSE );
   }
 
@@ -1645,7 +1696,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
     *y2 = rarr[4];
     *z2 = rarr[5];
     *rad= rarr[6];
-    free_ptr( (void **)&startptr );
+    Mem_Free( (void **)&startptr );
     return( TRUE );
   }
 
@@ -1669,7 +1720,7 @@ readgm( char *gm, int *i1, int *i2, double *x1,
   *z2  = rarr[5];
   *rad = rarr[6];
 
-  free_ptr( (void **)&startptr );
+  Mem_Free( (void **)&startptr );
   return( TRUE );
 } /* readgm() */
 
