@@ -17,59 +17,14 @@
 #ifndef INPUT_H
 #define INPUT_H     1
 
-#include "common.h"
-#include <ctype.h>
+#include <gtk/gtk.h>
 
-#define COMMANDS \
-  "CM", "CP", "EK", "EN", "EX", \
-  "FR", "GD", "GN", "KH", "LD", \
-  "NE", "NH", "NT", "PQ", "PT", \
-  "RP", "SY", "TL", "XQ", "ZO"
-
-/* Command Mnemonics */
-enum CMND_MNM
-{
-  CM = 0,
-  CP,
-  EK,
-  EN,
-  EX,
-  FR,
-  GD,
-  GN,
-  KH,
-  LD,
-  NE,
-  NH,
-  NT,
-  PQ,
-  PT,
-  RP,
-  SY,
-  TL,
-  XQ,
-  ZO,
-  NUM_CMNDS
-};
-
-/* Geometry Mnemonics */
-enum GEOM_MNM
-{
-  GW = 0,
-  GX,
-  GR,
-  GS,
-  GE,
-  GM,
-  SP,
-  SM,
-  GA,
-  SC,
-  GH,
-  GF,
-  CT,
-  NUM_GEOMN
-};
+/* input.c */
+gboolean Read_Comments(void);
+gboolean Read_Geometry(void);
+gboolean Read_Commands(void);
+gboolean readmn(char *mn, int *i1, int *i2, int *i3, int *i4, double *f1, double *f2, double *f3, double *f4, double *f5, double *f6);
+gboolean readgm(char *gm, int *i1, int *i2, double *x1, double *y1, double *z1, double *x2, double *y2, double *z2, double *rad);
 
 #endif
 
