@@ -15,9 +15,30 @@
  */
 
 #include "main.h"
+#include "callback_func.h"
+#include "common.h"
+#include "draw.h"
+#include "draw_structure.h"
+#include "editors.h"
+#include "input.h"
+#include "interface.h"
+#include "nec2_model.h"
+#include "rc_config.h"
 #include "shared.h"
+#include "utils.h"
+#include "xnec2c.h"
 
-static void sig_handler(int signal);
+#include <gtk/gtk.h>
+#include <getopt.h>
+
+#define OPEN_INPUT_FLAGS \
+  RDPAT_FLAGS       | \
+  FREQ_LOOP_FLAGS   | \
+  PLOT_FREQ_LINE    | \
+  ENABLE_EXCITN     | \
+  INPUT_OPENED
+
+static void sig_handler( int signal );
 
 /* Child process pid returned by fork() */
 static pid_t child_pid = (pid_t)(-1);
@@ -137,7 +158,7 @@ main (int argc, char *argv[])
         break;
 
       case 'h': /* print usage and exit */
-        usage();
+        Usage();
         exit(0);
 
       case 'v': /* print xnec2c version */
@@ -145,7 +166,7 @@ main (int argc, char *argv[])
         exit(0);
 
       default:
-        usage();
+        Usage();
         exit(0);
 
     } /* switch( option ) */
@@ -176,12 +197,12 @@ main (int argc, char *argv[])
   if( calc_data.num_jobs > 1 )
   {
     size_t mreq = (size_t)calc_data.num_jobs * sizeof(forked_proc_data_t *);
-    mem_alloc( (void **)&forked_proc_data, mreq, "in main.c" );
+    Mem_Alloc( (void **)&forked_proc_data, mreq, "in main.c" );
     for( idx = 0; idx < calc_data.num_jobs; idx++ )
     {
       forked_proc_data[idx] = NULL;
       mreq = sizeof(forked_proc_data_t);
-      mem_alloc( (void **)&forked_proc_data[idx], mreq, "in main.c" );
+      Mem_Alloc( (void **)&forked_proc_data[idx], mreq, "in main.c" );
     }
 
     /* Fork child processes */
@@ -360,7 +381,7 @@ Open_Input_File( gpointer arg )
 
     /* Close plot/rdpat windows if open */
     Gtk_Widget_Destroy( &rdpattern_window );
-    Gtk_Widget_Destroy( &freqplots_window );
+    Gtk_Widget_Destroy( &plots_window );
 
     if( nec2_edit_window == NULL )
       Open_Nec2_Editor( NEC2_EDITOR_RELOAD );
@@ -370,8 +391,9 @@ Open_Input_File( gpointer arg )
     return( FALSE );
   } /* if( !ok ) */
 
-  // The optimizer can queue multiple calls to this function so protect it with a lock
-  g_mutex_lock (&mutex);
+  // The optimizer can queue multiple calls to
+  // this function so protect it with a lock
+  g_mutex_lock( &mutex );
 
   SetFlag( INPUT_OPENED );
   gtk_widget_show( Builder_Get_Object(main_window_builder, "optimizer_output") );
@@ -476,11 +498,11 @@ Open_Input_File( gpointer arg )
   /* Re-initiate frequency plots if window open */
   if( isFlagSet(PLOT_ENABLED) )
   {
-    GtkWidget *box = Builder_Get_Object( freqplots_window_builder, "freqplots_box" );
+    GtkWidget *box = Builder_Get_Object( plots_window_builder, "plots_box" );
     gtk_widget_show( box );
     if( rc_config.main_loop_start )
     {
-      Main_Freqplots_Activate();
+      Main_Plots_Activate();
       Start_Frequency_Loop();
     }
   }
@@ -517,7 +539,7 @@ Open_Input_File( gpointer arg )
   }
 
   // Unlock the mutex:
-  g_mutex_unlock (&mutex);
+  g_mutex_unlock( &mutex );
 
   return( FALSE );
 } /* Open_Input_File() */
