@@ -40,7 +40,20 @@
  ***********************************************************************/
 
 #include "matrix.h"
+#include "calculations.h"
+#include "fields.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <complex.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
+
+#define RETA    2.654420938E-3
 
 /*-------------------------------------------------------------------*/
 
@@ -585,7 +598,7 @@ cmset( int nrow, complex double *cmx, double rkhx, int iexkx )
 
   /* Allocate to scratch memory */
   size_t mreq = (size_t)data.np2m * sizeof(complex double);
-  mem_alloc( (void **)&scm, mreq, "in matrix.c");
+  Mem_Alloc( (void **)&scm, mreq, "in matrix.c");
 
   /* combine elements for symmetry modes */
   for( i = 0; i < it; i++ )
@@ -622,7 +635,7 @@ cmset( int nrow, complex double *cmx, double rkhx, int iexkx )
 
   } /* for( i = 0; i < it; i++ ) */
 
-  free_ptr( (void **)&scm );
+  Mem_Free( (void **)&scm );
 
   return;
 }
@@ -638,7 +651,7 @@ cmsw( int j1, int j2, int i1, int i2, complex double *cmx,
   static complex double *emel = NULL;
 
   size_t mreq = 9 * sizeof(complex double);
-  mem_alloc( (void **)&emel, mreq, "in matrix.c");
+  Mem_Alloc( (void **)&emel, mreq, "in matrix.c");
 
   jsnox = segj.jsno-1;
 
@@ -1131,7 +1144,7 @@ factr( int n, complex double *a, int *ip, int ndim)
 
   /* Allocate to scratch memory */
   size_t mreq = (size_t)data.np2m * sizeof(complex double);
-  mem_alloc( (void **)&scm, mreq, "in matrix.c");
+  Mem_Alloc( (void **)&scm, mreq, "in matrix.c");
 
   /* Un-transpose the matrix for Gauss elimination */
   for( i = 1; i < n; i++ )
@@ -1161,8 +1174,7 @@ factr( int n, complex double *a, int *ip, int ndim)
         scm[pj]= scm[j];
         jp1= j+1;
 
-        #pragma GCC unroll 128
-        #pragma GCC ivdep
+        // FIXME below loop may be unrolled for faster execution
         for( i = jp1; i < n; i++ )
           scm[i] -= a[i+j*ndim]* arj;
 
@@ -1213,7 +1225,7 @@ factr( int n, complex double *a, int *ip, int ndim)
 
   } /* for( r=0; r < n; r++ ) */
 
-  free_ptr( (void **)&scm );
+  Mem_Free( (void **)&scm );
 
   return;
 }
@@ -1332,7 +1344,7 @@ solve( int n, complex double *a, int *ip,
 
   /* Allocate to scratch memory */
   size_t mreq = (size_t)data.np2m * sizeof(complex double);
-  mem_alloc( (void **)&scm, mreq, "in matrix.c");
+  Mem_Alloc( (void **)&scm, mreq, "in matrix.c");
 
   /* forward substitution */
   for( i = 0; i < n; i++ )
@@ -1361,7 +1373,7 @@ solve( int n, complex double *a, int *ip,
     b[i]=( scm[i]- sum)/ a[i+i*ndim];
   }
 
-  free_ptr( (void **)&scm );
+  Mem_Free( (void **)&scm );
 
   return;
 }
@@ -1388,7 +1400,7 @@ solves( complex double *a, int *ip,
 
   /* Allocate to scratch memory */
   size_t mreq = (size_t)data.np2m * sizeof(complex double);
-  mem_alloc( (void **)&scm, mreq, "in matrix.c");
+  Mem_Alloc( (void **)&scm, mreq, "in matrix.c");
 
   if( smat.nop != 1)
   {
@@ -1476,7 +1488,7 @@ solves( complex double *a, int *ip,
 
   if( smat.nop == 1)
   {
-    free_ptr( (void **)&scm );
+    Mem_Free( (void **)&scm );
     return;
   }
 
@@ -1547,7 +1559,7 @@ solves( complex double *a, int *ip,
 
   } /* for( ic = 0; ic < nrh; ic++ ) */
 
-  free_ptr( (void **)&scm );
+  Mem_Free( (void **)&scm );
 
   return;
 }
