@@ -17,9 +17,7 @@
 #ifndef NEC2_MODEL_H
 #define NEC2_MODEL_H    1
 
-#include "common.h"
-#include "interface.h"
-#include "editors.h"
+#include <gtk/gtk.h>
 
 /* Commands for the NEC2 file editor */
 enum NEC2_CMND
@@ -30,5 +28,10 @@ enum NEC2_CMND
   NEC2_EDITOR_CLEAR
 };
 
+/* nec2_model.c */
+void Nec2_Input_File_Treeview(int action);
+void cell_edited_callback(GtkCellRendererText *cell, gchar *path, gchar *new_text, gpointer user_data);
+void Save_Nec2_Input_File(GtkWidget *treeview_window, char *nec2_file);
+
 #endif
 
