@@ -40,14 +40,25 @@
  ***********************************************************************/
 
 #include "network.h"
+#include "calculations.h"
+#include "matrix.h"
 #include "shared.h"
+#include "utils.h"
+
+#include <complex.h>
+#include <math.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
 
 /*-------------------------------------------------------------------*/
 
 /* subroutine netwk solves for structure currents for a given */
 /* excitation including the effect of non-radiating networks if */
 /* present. */
-void
+  void
 netwk( complex double *cmx, int *ip, complex double *einc )
 {
   int *ipnt = NULL, *nteqa = NULL, *ntsca = NULL;
@@ -67,25 +78,25 @@ netwk( complex double *cmx, int *ip, complex double *einc )
   if( netcx.nonet > 0 )
   {
     mreq = (size_t)data.np3m * sizeof(complex double);
-    mem_alloc( (void **)&rhs, mreq, "in network.c");
+    Mem_Alloc( (void **)&rhs, mreq, "in network.c");
 
     mreq = (size_t)j * sizeof(complex double);
-    mem_alloc( (void **)&rhnt, mreq, "in network.c");
-    mem_alloc( (void **)&rhnx, mreq, "in network.c");
-    mem_alloc( (void **)&cmn,  mreq * (size_t)j, "in network.c");
+    Mem_Alloc( (void **)&rhnt, mreq, "in network.c");
+    Mem_Alloc( (void **)&rhnx, mreq, "in network.c");
+    Mem_Alloc( (void **)&cmn,  mreq * (size_t)j, "in network.c");
 
     mreq = (size_t)j * sizeof(int);
-    mem_alloc( (void **)&ntsca, mreq, "in network.c");
-    mem_alloc( (void **)&nteqa, mreq, "in network.c");
-    mem_alloc( (void **)&ipnt,  mreq, "in network.c");
+    Mem_Alloc( (void **)&ntsca, mreq, "in network.c");
+    Mem_Alloc( (void **)&nteqa, mreq, "in network.c");
+    Mem_Alloc( (void **)&ipnt,  mreq, "in network.c");
 
     mreq = (size_t)vsorc.nsant * sizeof(complex double);
-    mem_alloc( (void **)&vsrc, mreq, "in network.c");
+    Mem_Alloc( (void **)&vsrc, mreq, "in network.c");
   }
   else if( netcx.masym != 0)
   {
     mreq = (size_t)j * sizeof(int);
-    mem_alloc( (void **)&ipnt,  mreq, "in network.c");
+    Mem_Alloc( (void **)&ipnt,  mreq, "in network.c");
   }
 
   /* Signal new and valid current data */
@@ -517,14 +528,14 @@ netwk( complex double *cmx, int *ip, complex double *einc )
   if( (vsorc.nsant+vsorc.nvqd) == 0)
   {
     /* Free network buffers */
-    free_ptr( (void **)&ipnt );
-    free_ptr( (void **)&nteqa );
-    free_ptr( (void **)&ntsca );
-    free_ptr( (void **)&vsrc );
-    free_ptr( (void **)&rhs );
-    free_ptr( (void **)&cmn );
-    free_ptr( (void **)&rhnt );
-    free_ptr( (void **)&rhnx );
+    Mem_Free( (void **)&ipnt );
+    Mem_Free( (void **)&nteqa );
+    Mem_Free( (void **)&ntsca );
+    Mem_Free( (void **)&vsrc );
+    Mem_Free( (void **)&rhs );
+    Mem_Free( (void **)&cmn );
+    Mem_Free( (void **)&rhnt );
+    Mem_Free( (void **)&rhnx );
     return;
   }
 
@@ -582,14 +593,14 @@ netwk( complex double *cmx, int *ip, complex double *einc )
     } /* for( i = 0; i < vsorc.nvqd; i++ ) */
 
   /* Free network buffers */
-  free_ptr( (void **)&ipnt );
-  free_ptr( (void **)&nteqa );
-  free_ptr( (void **)&ntsca );
-  free_ptr( (void **)&vsrc );
-  free_ptr( (void **)&rhs );
-  free_ptr( (void **)&cmn );
-  free_ptr( (void **)&rhnt );
-  free_ptr( (void **)&rhnx );
+  Mem_Free( (void **)&ipnt );
+  Mem_Free( (void **)&nteqa );
+  Mem_Free( (void **)&ntsca );
+  Mem_Free( (void **)&vsrc );
+  Mem_Free( (void **)&rhs );
+  Mem_Free( (void **)&cmn );
+  Mem_Free( (void **)&rhnt );
+  Mem_Free( (void **)&rhnx );
 
   return;
 }
@@ -645,7 +656,7 @@ load( int *ldtyp, int *ldtag, int *ldtagf, int *ldtagt,
       fprintf( stderr,
           _("xnec2c: load(): improper load type chosen,"
           " requested type is %d\n"), ldtyp[istepx] );
-      Stop( _("load(): Improper load type chose"), ERR_STOP );
+      Stop( _("load(): Improper load type chosen"), ERR_STOP );
     }
 
     /* search segments for proper itags */
