@@ -17,6 +17,8 @@
 #ifndef OPTIMIZE_H
 #define OPTIMIZE_H    1
 
-#include "common.h"
+/* optimize.c */
+void Write_Optimizer_Data(void);
+void *Optimizer_Output(void *arg);
 
 #endif
