@@ -15,6 +15,13 @@
  */
 
 #include "rc_config.h"
+#include "interface.h"
+#include "shared.h"
+#include "utils.h"
+
+#include <ctype.h>
+#include <gtk/gtk.h>
+#include <sys/stat.h>
 
 /*------------------------------------------------------------------------*/
 
@@ -126,18 +133,18 @@ Create_Default_Config( void )
   rc_config.rdpattern_zoom_spinbutton = 100;
 
   /* For freq plots window */
-  rc_config.freqplots_width  = 0;
-  rc_config.freqplots_height = 0;
-  rc_config.freqplots_x = 0;
-  rc_config.freqplots_y = 0;
-  rc_config.freqplots_gmax_togglebutton    = 0;
-  rc_config.freqplots_gdir_togglebutton    = 0;
-  rc_config.freqplots_gviewer_togglebutton = 0;
-  rc_config.freqplots_vswr_togglebutton    = 0;
-  rc_config.freqplots_zrlzim_togglebutton  = 0;
-  rc_config.freqplots_zmgzph_togglebutton  = 0;
-  rc_config.freqplots_smith_togglebutton   = 0;
-  rc_config.freqplots_net_gain = 0;
+  rc_config.plots_width  = 0;
+  rc_config.plots_height = 0;
+  rc_config.plots_x      = 0;
+  rc_config.plots_y      = 0;
+  rc_config.plots_gmax_togglebutton    = 0;
+  rc_config.plots_gdir_togglebutton    = 0;
+  rc_config.plots_gviewer_togglebutton = 0;
+  rc_config.plots_vswr_togglebutton    = 0;
+  rc_config.plots_zrlzim_togglebutton  = 0;
+  rc_config.plots_zmgzph_togglebutton  = 0;
+  rc_config.plots_smith_togglebutton   = 0;
+  rc_config.plots_net_gain = 0;
 
   /* For NEC2 editor window */
   rc_config.nec2_edit_width  = 0;
@@ -196,10 +203,10 @@ Restore_Windows( gpointer dat )
   GtkWidget *widget;
 
   /* Open frequency plots window if state data available */
-  if( rc_config.freqplots_width &&
-      rc_config.freqplots_height )
+  if( rc_config.plots_width &&
+      rc_config.plots_height )
   {
-    widget = Builder_Get_Object( main_window_builder, "main_freqplots" );
+    widget = Builder_Get_Object( main_window_builder, "main_plots" );
     gtk_menu_item_activate( GTK_MENU_ITEM(widget) );
   }
 
@@ -546,10 +553,10 @@ Read_Config( void )
     return( FALSE );
   }
   idx = 0;
-  rc_config.freqplots_width = atoi( line );
+  rc_config.plots_width = atoi( line );
   do idx++;
   while( (idx < LINE_LEN - 2) && (line[idx] != ',') );
-  rc_config.freqplots_height = atoi( &line[idx + 1] );
+  rc_config.plots_height = atoi( &line[idx + 1] );
 
   /* Read frequency plots window position */
   if( Load_Line(line, fp) == EOF )
@@ -559,10 +566,10 @@ Read_Config( void )
     return( FALSE );
   }
   idx = 0;
-  rc_config.freqplots_x = atoi( line );
+  rc_config.plots_x = atoi( line );
   do idx++;
   while( (idx < LINE_LEN - 2) && (line[idx] != ',') );
-  rc_config.freqplots_y = atoi( &line[idx + 1] );
+  rc_config.plots_y = atoi( &line[idx + 1] );
 
   /* Read frequency plots window Max Gain toggle button state */
   if( Load_Line(line, fp) == EOF )
@@ -571,7 +578,7 @@ Read_Config( void )
         _("xnec2c: failed to read Frequency Plots window GMax toggle state\n") );
     return( FALSE );
   }
-  rc_config.freqplots_gmax_togglebutton = (uint8_t)atoi( line );
+  rc_config.plots_gmax_togglebutton = (uint8_t)atoi( line );
 
   /* Read frequency plots window Gain Direction toggle button state */
   if( Load_Line(line, fp) == EOF )
@@ -580,7 +587,7 @@ Read_Config( void )
         _("xnec2c: failed to read Frequency Plots window GDir toggle state\n") );
     return( FALSE );
   }
-  rc_config.freqplots_gdir_togglebutton = (uint8_t)atoi( line );
+  rc_config.plots_gdir_togglebutton = (uint8_t)atoi( line );
 
   /* Read frequency plots window Gain in Viewer direction toggle button state */
   if( Load_Line(line, fp) == EOF )
@@ -589,7 +596,7 @@ Read_Config( void )
         _("xnec2c: failed to read Frequency Plots window GViewer toggle state\n") );
     return( FALSE );
   }
-  rc_config.freqplots_gviewer_togglebutton = (uint8_t)atoi( line );
+  rc_config.plots_gviewer_togglebutton = (uint8_t)atoi( line );
 
   /* Read frequency plots window VSWR toggle button state */
   if( Load_Line(line, fp) == EOF )
@@ -598,7 +605,7 @@ Read_Config( void )
         _("xnec2c: failed to read Frequency Plots window VSWR toggle state\n") );
     return( FALSE );
   }
-  rc_config.freqplots_vswr_togglebutton = (uint8_t)atoi( line );
+  rc_config.plots_vswr_togglebutton = (uint8_t)atoi( line );
 
   /* Read frequency plots window Z-real/Z-imag toggle button state */
   if( Load_Line(line, fp) == EOF )
@@ -607,7 +614,7 @@ Read_Config( void )
         _("xnec2c: failed to read Frequency Plots window Z-real/Z-imag toggle state\n") );
     return( FALSE );
   }
-  rc_config.freqplots_zrlzim_togglebutton = (uint8_t)atoi( line );
+  rc_config.plots_zrlzim_togglebutton = (uint8_t)atoi( line );
 
   /* Read frequency plots window Z-mag/Z-phase toggle button state */
   if( Load_Line(line, fp) == EOF )
@@ -616,7 +623,7 @@ Read_Config( void )
         _("xnec2c: failed to read Frequency Plots window Z-mag/Z-phase toggle state\n") );
     return( FALSE );
   }
-  rc_config.freqplots_zmgzph_togglebutton = (uint8_t)atoi( line );
+  rc_config.plots_zmgzph_togglebutton = (uint8_t)atoi( line );
 
   /* Read frequency plots window smith toggle button state */
   if( Load_Line(line, fp) == EOF )
@@ -625,7 +632,7 @@ Read_Config( void )
         _("xnec2c: failed to read Frequency Plots window smith toggle state\n") );
     return( FALSE );
   }
-  rc_config.freqplots_smith_togglebutton = (uint8_t)atoi( line );
+  rc_config.plots_smith_togglebutton = (uint8_t)atoi( line );
 
   /* Read frequency plots window Net Gain menu item state */
   if( Load_Line(line, fp) == EOF )
@@ -634,7 +641,7 @@ Read_Config( void )
         _("xnec2c: failed to read Frequency Plots window Net Gain menu item state\n") );
     return( FALSE );
   }
-  rc_config.freqplots_net_gain = (uint8_t)atoi( line );
+  rc_config.plots_net_gain = (uint8_t)atoi( line );
 
   /* Read NEC2 editor window size */
   if( Load_Line(line, fp) == EOF )
@@ -809,60 +816,60 @@ Get_GUI_State( void )
   }
 
   /* Get geometry of frequency plots window */
-  Get_Window_Geometry( freqplots_window,
-      &(rc_config.freqplots_x), &(rc_config.freqplots_y),
-      &(rc_config.freqplots_width), &(rc_config.freqplots_height) );
+  Get_Window_Geometry( plots_window,
+      &(rc_config.plots_x), &(rc_config.plots_y),
+      &(rc_config.plots_width), &(rc_config.plots_height) );
 
   /* Get state of widgets in frequency plots window */
-  rc_config.freqplots_gmax_togglebutton    = 0;
-  rc_config.freqplots_gdir_togglebutton    = 0;
-  rc_config.freqplots_gviewer_togglebutton = 0;
-  rc_config.freqplots_vswr_togglebutton    = 0;
-  rc_config.freqplots_zrlzim_togglebutton  = 0;
-  rc_config.freqplots_zmgzph_togglebutton  = 0;
-  rc_config.freqplots_smith_togglebutton   = 0;
-  rc_config.freqplots_net_gain = 0;
-  if( freqplots_window )
+  rc_config.plots_gmax_togglebutton    = 0;
+  rc_config.plots_gdir_togglebutton    = 0;
+  rc_config.plots_gviewer_togglebutton = 0;
+  rc_config.plots_vswr_togglebutton    = 0;
+  rc_config.plots_zrlzim_togglebutton  = 0;
+  rc_config.plots_zmgzph_togglebutton  = 0;
+  rc_config.plots_smith_togglebutton   = 0;
+  rc_config.plots_net_gain = 0;
+  if( plots_window )
   {
     widget = Builder_Get_Object(
-        freqplots_window_builder, "freqplots_gmax_togglebutton" );
+        plots_window_builder, "plots_gmax_togglebutton" );
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) )
-      rc_config.freqplots_gmax_togglebutton = 1;
+      rc_config.plots_gmax_togglebutton = 1;
 
     widget = Builder_Get_Object(
-        freqplots_window_builder, "freqplots_gdir_togglebutton" );
+        plots_window_builder, "plots_gdir_togglebutton" );
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) )
-      rc_config.freqplots_gdir_togglebutton = 1;
+      rc_config.plots_gdir_togglebutton = 1;
 
     widget = Builder_Get_Object(
-        freqplots_window_builder, "freqplots_gviewer_togglebutton" );
+        plots_window_builder, "plots_gviewer_togglebutton" );
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) )
-      rc_config.freqplots_gviewer_togglebutton = 1;
+      rc_config.plots_gviewer_togglebutton = 1;
 
     widget = Builder_Get_Object(
-        freqplots_window_builder, "freqplots_vswr_togglebutton" );
+        plots_window_builder, "plots_vswr_togglebutton" );
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) )
-      rc_config.freqplots_vswr_togglebutton = 1;
+      rc_config.plots_vswr_togglebutton = 1;
 
     widget = Builder_Get_Object(
-        freqplots_window_builder, "freqplots_zrlzim_togglebutton" );
+        plots_window_builder, "plots_zrlzim_togglebutton" );
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) )
-      rc_config.freqplots_zrlzim_togglebutton = 1;
+      rc_config.plots_zrlzim_togglebutton = 1;
 
     widget = Builder_Get_Object(
-        freqplots_window_builder, "freqplots_zmgzph_togglebutton" );
+        plots_window_builder, "plots_zmgzph_togglebutton" );
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) )
-      rc_config.freqplots_zmgzph_togglebutton = 1;
+      rc_config.plots_zmgzph_togglebutton = 1;
 
     widget = Builder_Get_Object(
-        freqplots_window_builder, "freqplots_net_gain" );
+        plots_window_builder, "plots_net_gain" );
     if( gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget)) )
-      rc_config.freqplots_net_gain = 1;
+      rc_config.plots_net_gain = 1;
 
     widget = Builder_Get_Object(
-        freqplots_window_builder, "freqplots_smith_togglebutton" );
+        plots_window_builder, "plots_smith_togglebutton" );
     if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)) )
-      rc_config.freqplots_smith_togglebutton = 1;
+      rc_config.plots_smith_togglebutton = 1;
   }
 
   /* Get geometry of NEC2 editor window */
@@ -922,18 +929,18 @@ Save_Config( void )
       rc_config.rdpattern_h_field,
       rc_config.rdpattern_poynting_vector,
       rc_config.rdpattern_zoom_spinbutton,
-      rc_config.freqplots_width,
-      rc_config.freqplots_height,
-      rc_config.freqplots_x,
-      rc_config.freqplots_y,
-      rc_config.freqplots_gmax_togglebutton,
-      rc_config.freqplots_gdir_togglebutton,
-      rc_config.freqplots_gviewer_togglebutton,
-      rc_config.freqplots_vswr_togglebutton,
-      rc_config.freqplots_zrlzim_togglebutton,
-      rc_config.freqplots_zmgzph_togglebutton,
-      rc_config.freqplots_smith_togglebutton,
-      rc_config.freqplots_net_gain,
+      rc_config.plots_width,
+      rc_config.plots_height,
+      rc_config.plots_x,
+      rc_config.plots_y,
+      rc_config.plots_gmax_togglebutton,
+      rc_config.plots_gdir_togglebutton,
+      rc_config.plots_gviewer_togglebutton,
+      rc_config.plots_vswr_togglebutton,
+      rc_config.plots_zrlzim_togglebutton,
+      rc_config.plots_zmgzph_togglebutton,
+      rc_config.plots_smith_togglebutton,
+      rc_config.plots_net_gain,
       rc_config.nec2_edit_width,
       rc_config.nec2_edit_height,
       rc_config.nec2_edit_x,
