@@ -14,18 +14,31 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include "utils.h"
+#include "interface.h"
+#include "main.h"
 #include "shared.h"
+#include "xnec2c.h"
+
+#include <gtk/gtk.h>
+
+/* Carriage return and line feed */
+#define CR  0x0d
+#define LF  0x0a
 
 /*------------------------------------------------------------------------*/
 
-/*  usage()
+/*  Usage()
  *
  *  Prints usage information
  */
 
   void
-usage(void)
+Usage(void)
 {
   fprintf( stderr,
       _("Usage: xnec2c <input-file-name>\n"
@@ -34,12 +47,12 @@ usage(void)
         "              [-h: print this usage information and exit]\n"
         "              [-v: print xnec2c version number and exit]\n") );
 
-} /* end of usage() */
+} /* Usage() */
 
 /*------------------------------------------------------------------------*/
 
 /* Does the STOP function of fortran but with a warning dialog */
-  int
+  void
 Stop( char *mesg, int err )
 {
   GtkBuilder *builder;
@@ -52,9 +65,9 @@ Stop( char *mesg, int err )
     {
       fprintf( stderr,
           _("xnec2c: fatal: child process %d exiting\n"), num_child_procs );
-      _exit(-1);
+      _exit( -1 );
     }
-    else return( err );
+    else return;
 
   } /* if( CHILD ) */
 
@@ -75,19 +88,19 @@ Stop( char *mesg, int err )
     g_object_unref( builder );
   }
 
-  /* Loop over usleep till user decides what to do */
+  /* Loop over usleep till user decides what to do. */
   /* Could not think of another way to do this :-( */
   SetFlag( ERROR_CONDX );
   while( isFlagSet(ERROR_CONDX) )
   {
-    if( isFlagSet(MAIN_QUIT) ) exit(-1);
+    if( isFlagSet(MAIN_QUIT) ) exit( -1 );
 
     /* Wait for GTK to complete its tasks */
     while( g_main_context_iteration(NULL, FALSE) );
-    usleep(100000);
+    usleep( 100000 );
   }
 
-  return( err );
+  return;
 } /* Stop() */
 
 /*------------------------------------------------------------------*/
@@ -198,54 +211,48 @@ Load_Line( char *buff, FILE *pfile )
 /*------------------------------------------------------------------------*/
 
 /***  Memory allocation/freeing utils ***/
-static size_t cnt = 0; /* Total allocation */
   void
-mem_alloc( void **ptr, size_t req, gchar *str )
+Mem_Alloc( void **ptr, size_t req, gchar *str )
 {
   gchar mesg[MESG_SIZE];
 
-  free_ptr( ptr );
+  Mem_Free( ptr );
   *ptr = malloc( req );
-  cnt += req;
   if( *ptr == NULL )
   {
     snprintf( mesg, sizeof(mesg),
         _("Memory allocation denied %s\n"), str );
-    fprintf( stderr, "%s: Total memory request %lu\n", mesg, cnt );
-    Stop( mesg, ERR_STOP );
+    exit( -1 );
   }
 
-} /* End of mem_alloc() */
+} /* End of Mem_Alloc() */
 
 /*------------------------------------------------------------------------*/
 
   void
-mem_realloc( void **ptr, size_t req, gchar *str )
+Mem_Realloc( void **ptr, size_t req, gchar *str )
 {
   gchar mesg[MESG_SIZE];
 
   *ptr = realloc( *ptr, req );
-  cnt += req;
   if( *ptr == NULL )
   {
-    snprintf( mesg, sizeof(mesg),
-        _("Memory re-allocation denied %s\n"), str );
-    fprintf( stderr, "%s: Total memory request %lu\n", mesg, cnt );
-    Stop( mesg, ERR_STOP );
+    snprintf( mesg, sizeof(mesg), _("Memory re-allocation denied %s\n"), str );
+    exit( -1 );
   }
 
-} /* End of mem_realloc() */
+} /* End of Mem_Realloc() */
 
 /*------------------------------------------------------------------------*/
 
   void
-free_ptr( void **ptr )
+Mem_Free( void **ptr )
 {
   if( *ptr != NULL )
     free( *ptr );
   *ptr = NULL;
 
-} /* End of free_ptr() */
+} /* End of Mem_Free() */
 
 /*------------------------------------------------------------------------*/
 
@@ -333,18 +340,6 @@ ClearFlag( unsigned long long int flag )
   Flags &= ~flag;
 }
 
-  void
-ToggleFlag( unsigned long long int flag )
-{
-  Flags ^= flag;
-}
-
-  void
-SaveFlag( unsigned long long int *flag, unsigned long long int mask )
-{
-  *flag |= (Flags & mask);
-}
-
 /*------------------------------------------------------------------------*/
 
 /* Strlcpy()
