@@ -13,9 +13,32 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-
 #include "xnec2c.h"
+#include "callback_func.h"
+#include "calculations.h"
+#include "common.h"
+#include "draw_structure.h"
+#include "fields.h"
+#include "interface.h"
+#include "matrix.h"
+#include "main.h"
+#include "network.h"
+#include "optimize.h"
+#include "plot_freqdata.h"
+#include "radiation.h"
 #include "shared.h"
+#include "somnec.h"
+#include "utils.h"
+
+#include <complex.h>
+#include <gtk/gtk.h>
+#include <math.h>
+#include <pthread.h>
+
+#undef _Complex_I
+#define _Complex_I  (__extension__ 1.0i)
+#undef I
+#define I _Complex_I
 
 /* Left-overs from fortran code :-( */
 static double tmp1, tmp2, tmp3, tmp4, tmp5, tmp6;
@@ -159,7 +182,7 @@ Set_Interaction_Matrix( void )
   /* Memory allocation for symmetry array */
   smat.nop = netcx.neq/netcx.npeq;
   size_t mreq = (size_t)(smat.nop * smat.nop) * sizeof( complex double);
-  mem_realloc( (void **)&smat.ssx, mreq, "in xnec2c.c" );
+  Mem_Realloc( (void **)&smat.ssx, mreq, "in xnec2c.c" );
 
   /* irngf is not used (NGF function not implemented) */
   int iresrv = data.np2m * (data.np + 2 * data.mp);
@@ -472,7 +495,7 @@ Frequency_Loop( gpointer udata )
   ClearFlag( FREQ_LOOP_INIT );
 
   // Prevent the optimizer from running this function in parallel:
-  g_mutex_lock (&mutex);
+  g_mutex_lock( &mutex );
   
   // Synchronize here to get the flags setup when all the async callbacks finish:
   while( g_main_context_iteration(NULL, FALSE) );
@@ -650,12 +673,12 @@ Frequency_Loop( gpointer udata )
     char txt[10];
     snprintf( txt, sizeof(txt), "%9.3f", calc_data.freq_mhz );
     gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
-            freqplots_window_builder, "freqplots_fmhz_entry")), txt );
+            plots_window_builder, "plots_fmhz_entry")), txt );
 
     /* Wait for GTK to complete its tasks */
     if( isFlagClear(OPTIMIZER_OUTPUT) )
     {
-      gtk_widget_queue_draw( freqplots_drawingarea );
+      gtk_widget_queue_draw( plots_drawingarea );
       //while( g_main_context_iteration(NULL, FALSE) );
     }
   }
@@ -697,13 +720,13 @@ Frequency_Loop( gpointer udata )
         char txt[10];
         snprintf( txt, sizeof(txt), "%9.3f", calc_data.fmhz_save );
         gtk_entry_set_text( GTK_ENTRY(Builder_Get_Object(
-                freqplots_window_builder, "freqplots_fmhz_entry")), txt );
+                plots_window_builder, "plots_fmhz_entry")), txt );
       }
     }
 
     /* Re-draw drawing areas at end of loop */
     if( isFlagSet(PLOT_ENABLED) )
-      gtk_widget_queue_draw( freqplots_drawingarea );
+      gtk_widget_queue_draw( plots_drawingarea );
     if( isFlagSet(DRAW_ENABLED) )
       gtk_widget_queue_draw( rdpattern_drawingarea );
     //while( g_main_context_iteration(NULL, FALSE) );
